@@ -314,9 +314,17 @@ static bg_record_t *_find_matching_block(List block_list,
 			continue;
 		} else if((bg_record->job_running != NO_JOB_RUNNING)
 			  && (bg_record->job_running != job_ptr->job_id)
-			  && (bg_conf->layout_mode == LAYOUT_DYNAMIC
-			      || (SELECT_IS_MODE_RUN_NOW(query_mode)
-				  && bg_conf->layout_mode != LAYOUT_DYNAMIC))) {
+			  && ((bg_conf->layout_mode == LAYOUT_DYNAMIC)
+			      || ((!SELECT_IS_CHECK_FULL_SET(query_mode)
+				   || SELECT_IS_MODE_RUN_NOW(query_mode))
+				  && (bg_conf->layout_mode
+				      != LAYOUT_DYNAMIC)))) {
+			/* Look here if you are trying to run now or
+			   if you aren't looking at the full set.  We
+			   don't continue on running blocks for the
+			   full set because we are seeing if the job
+			   can ever run so look here.
+			*/
 			debug("block %s in use by %s job %d",
 			      bg_record->bg_block_id,
 			      bg_record->user_name,
@@ -1525,6 +1533,10 @@ preempt:
 			} else if(bg_record->job_running == BLOCK_ERROR_STATE)
 				starttime = INFINITE;
 
+			/* make sure the job is eligible to run */
+			if(job_ptr->details->begin_time > starttime)
+				starttime = job_ptr->details->begin_time;
+
 			job_ptr->start_time = starttime;
 
 			select_g_select_jobinfo_set(job_ptr->select_jobinfo,
