@@ -980,6 +980,7 @@ void set_options(const int argc, char **argv)
 			opt.qos = xstrdup(optarg);
 			break;
 		case LONG_OPT_SOCKETSPERNODE:
+			max_val = 0;
 			get_resource_arg_range( optarg, "sockets-per-node",
 						&opt.min_sockets_per_node,
 						&max_val, true );
@@ -988,6 +989,7 @@ void set_options(const int argc, char **argv)
 				opt.min_sockets_per_node = NO_VAL;
 			break;
 		case LONG_OPT_CORESPERSOCKET:
+			max_val = 0;
 			get_resource_arg_range( optarg, "cores-per-socket",
 						&opt.min_cores_per_socket,
 						&max_val, true );
@@ -996,6 +998,7 @@ void set_options(const int argc, char **argv)
 				opt.min_cores_per_socket = NO_VAL;
 			break;
 		case LONG_OPT_THREADSPERCORE:
+			max_val = 0;
 			get_resource_arg_range( optarg, "threads-per-core",
 						&opt.min_threads_per_core,
 						&max_val, true );
@@ -1218,7 +1221,7 @@ static bool _opt_verify(void)
 
 	/* check for realistic arguments */
 	if (opt.nprocs <= 0) {
-		error("invalid number of processes (-n %d)",
+		error("invalid number of tasks (-n %d)",
 		      opt.nprocs);
 		verified = false;
 	}
