@@ -1302,6 +1302,7 @@ static void set_options(const int argc, char **argv)
 			opt.qos = xstrdup(optarg);
 			break;
 		case LONG_OPT_SOCKETSPERNODE:
+			max_val = 0;
 			get_resource_arg_range( optarg, "sockets-per-node",
 						&opt.min_sockets_per_node,
 						&max_val, true );
@@ -1310,6 +1311,7 @@ static void set_options(const int argc, char **argv)
 				opt.min_sockets_per_node = NO_VAL;
 			break;
 		case LONG_OPT_CORESPERSOCKET:
+			max_val = 0;
 			get_resource_arg_range( optarg, "cores-per-socket",
 						&opt.min_cores_per_socket,
 						&max_val, true );
@@ -1318,6 +1320,7 @@ static void set_options(const int argc, char **argv)
 				opt.min_cores_per_socket = NO_VAL;
 			break;
 		case LONG_OPT_THREADSPERCORE:
+			max_val = 0;
 			get_resource_arg_range( optarg, "threads-per-core",
 						&opt.min_threads_per_core,
 						&max_val, true );
@@ -1810,15 +1813,11 @@ static bool _opt_verify(void)
 		opt.nprocs = opt.min_nodes;
 
 		/* 1 proc / min_[socket * core * thread] default */
-		if (opt.min_sockets_per_node > 0) {
+		if ((opt.min_sockets_per_node != NO_VAL) &&
+		    (opt.min_cores_per_socket != NO_VAL) &&
+		    (opt.min_threads_per_core != NO_VAL)) {
 			opt.nprocs *= opt.min_sockets_per_node;
-			opt.nprocs_set = true;
-		}
-		if (opt.min_cores_per_socket > 0) {
 			opt.nprocs *= opt.min_cores_per_socket;
-			opt.nprocs_set = true;
-		}
-		if (opt.min_threads_per_core > 0) {
 			opt.nprocs *= opt.min_threads_per_core;
 			opt.nprocs_set = true;
 		}
