@@ -1,8 +1,8 @@
- /*****************************************************************************\
- *  test12.2.prog.c - Simple test program for SLURM regression test12.2.
- *  Usage: test12.2.prog <exit_code> <sleep_secs> <mem_kb>
+/*****************************************************************************\
+ *  prog1.39.prog.c - Simple program to generate segmentation violation and
+ *  generate a core file for use by test1.39.
  *****************************************************************************
- *  Copyright (C) 2005 The Regents of the University of California.
+ *  Copyright (C) 2004 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Morris Jette <jette1@llnl.gov>
  *  CODE-OCEC-09-009. All rights reserved.
@@ -25,33 +25,13 @@
  *  with SLURM; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
-#include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
-#include <unistd.h>
 
 main (int argc, char **argv)
 {
-	int exit_code, sleep_time, mem_kb;
-	char *mem;
+	char *a = NULL, b[1];
 
-	if (argc != 4) {
-		fprintf(stderr,
-			"Usage: %s <exit_code> <sleep_time> <mem_kb>\n",
-			argv[0]);
-		exit(1);
-	}
+	a[0] = b[0xffffffff];
 
-	exit_code  = atoi(argv[1]);
-	sleep_time = atoi(argv[2]);
-	mem_kb     = atoi(argv[3]);
-
-	mem = malloc(mem_kb * 1024);
-	/* need to do a memset on the memory or AIX will not give it
-	 * to me!
-	 */
-	memset(mem, 0, (mem_kb * 1024));
-	sleep(sleep_time);
-	free(mem);
-	exit(exit_code);
+	exit(0);
 }
